@@ -152,7 +152,9 @@ class BotAI(BotAIInternal):
     @property_cache_once_per_frame
     def expansion_locations_list(self) -> list[Point2]:
         """Returns a list of expansion positions, not sorted in any way."""
-        assert self._expansion_positions_list, "self._find_expansion_locations() has not been run yet, so accessing the list of expansion locations is pointless."
+        assert self._expansion_positions_list, (
+            "self._find_expansion_locations() has not been run yet, so accessing the list of expansion locations is pointless."
+        )
         return self._expansion_positions_list
 
     @property_cache_once_per_frame
@@ -163,16 +165,19 @@ class BotAI(BotAIInternal):
 
         Caution: This function is slow. If you only need the expansion locations, use the property above.
         """
-        assert self._expansion_positions_list, "self._find_expansion_locations() has not been run yet, so accessing the list of expansion locations is pointless."
+        assert self._expansion_positions_list, (
+            "self._find_expansion_locations() has not been run yet, so accessing the list of expansion locations is pointless."
+        )
         expansion_locations: dict[Point2, Units] = {pos: Units([], self) for pos in self._expansion_positions_list}
         for resource in self.resources:
             # It may be that some resources are not mapped to an expansion location
-            exp_position: Point2 | None = self._resource_location_to_expansion_position_dict.get(
+            exp_positions: set[Point2] | None = self._resource_location_to_expansion_position_dict.get(
                 resource.position, None
             )
-            if exp_position:
-                assert exp_position in expansion_locations
-                expansion_locations[exp_position].append(resource)
+            if exp_positions:
+                for exp_position in exp_positions:
+                    assert exp_position in expansion_locations
+                    expansion_locations[exp_position].append(resource)
         return expansion_locations
 
     @property
@@ -654,9 +659,9 @@ class BotAI(BotAIInternal):
             )
             return await self.can_place_single(building, positions)
         assert isinstance(positions, list), f"Expected an iterable (list, tuple), but was: {positions}"
-        assert isinstance(
-            positions[0], Point2
-        ), f"List is expected to have Point2, but instead had: {positions[0]} {type(positions[0])}"
+        assert isinstance(positions[0], Point2), (
+            f"List is expected to have Point2, but instead had: {positions[0]} {type(positions[0])}"
+        )
         return await self.client._query_building_placement_fast(building, positions)
 
     async def find_placement(
@@ -690,7 +695,7 @@ class BotAI(BotAIInternal):
             building = self.game_data.units[building.value].creation_ability.id
 
         if await self.can_place_single(building, near) and (
-            not addon_place or await self.can_place_single(UnitTypeId.SUPPLYDEPOT, near.offset((2.5, -0.5)))
+            not addon_place or await self.can_place_single(AbilityId.TERRANBUILD_SUPPLYDEPOT, near.offset((2.5, -0.5)))
         ):
             return near
 
@@ -714,7 +719,7 @@ class BotAI(BotAIInternal):
             if addon_place:
                 # Filter remaining positions if addon can be placed
                 res = await self.client._query_building_placement_fast(
-                    AbilityId.TERRANBUILDDROP_SUPPLYDEPOTDROP,
+                    AbilityId.TERRANBUILD_SUPPLYDEPOT,
                     [p.offset((2.5, -0.5)) for p in possible],
                 )
                 possible = [p for r, p in zip(res, possible) if r]
@@ -780,9 +785,9 @@ class BotAI(BotAIInternal):
 
         :param structure_type:
         """
-        assert isinstance(
-            structure_type, (int, UnitTypeId)
-        ), f"Needs to be int or UnitTypeId, but was: {type(structure_type)}"
+        assert isinstance(structure_type, (int, UnitTypeId)), (
+            f"Needs to be int or UnitTypeId, but was: {type(structure_type)}"
+        )
         if isinstance(structure_type, int):
             structure_type_value: int = structure_type
             structure_type = UnitTypeId(structure_type_value)
@@ -1111,9 +1116,9 @@ class BotAI(BotAIInternal):
 
         :param upgrade_type:
         """
-        assert (
-            upgrade_type in UPGRADE_RESEARCHED_FROM
-        ), f"Could not find upgrade {upgrade_type} in 'research from'-dictionary"
+        assert upgrade_type in UPGRADE_RESEARCHED_FROM, (
+            f"Could not find upgrade {upgrade_type} in 'research from'-dictionary"
+        )
 
         # Not affordable
         if not self.can_afford(upgrade_type):
@@ -1154,6 +1159,8 @@ class BotAI(BotAIInternal):
                 structure.type_id in research_structure_types
                 # If structure hasn't received an action/order this frame
                 and structure.tag not in self.unit_tags_received_action
+                # Structure is ready / completed
+                and structure.is_ready
                 # Structure is idle
                 and structure.is_idle
                 # Structure belongs to protoss and is powered (near pylon)
