@@ -101,7 +101,7 @@ transforming: dict[UnitTypeId, AbilityId] = {
     UnitTypeId.ZERGLING: AbilityId.BURROWUP_ZERGLING,
     UnitTypeId.ZERGLINGBURROWED: AbilityId.BURROWDOWN_ZERGLING,
 }
-# For now only contains units that cost supply, used in bot_ai.do()
+# For now only contains units that cost supply
 abilityid_to_unittypeid: dict[AbilityId, UnitTypeId] = {
     # Protoss
     AbilityId.NEXUSTRAIN_PROBE: UnitTypeId.PROBE,
@@ -408,6 +408,7 @@ PROTOSS_TECH_REQUIREMENT: dict[UnitTypeId, UnitTypeId] = defaultdict(
         UnitTypeId.ROBOTICSBAY: UnitTypeId.ROBOTICSFACILITY,
         UnitTypeId.COLOSSUS: UnitTypeId.ROBOTICSBAY,
         UnitTypeId.DISRUPTOR: UnitTypeId.ROBOTICSBAY,
+        UnitTypeId.FLEETBEACON: UnitTypeId.STARGATE,
     },
 )
 ZERG_TECH_REQUIREMENT: dict[UnitTypeId, UnitTypeId] = defaultdict(
