@@ -18,9 +18,9 @@ class PixelMap:
         # Used for copying pixelmaps
         self._in_bits: bool = in_bits
 
-        assert self.width * self.height == (8 if in_bits else 1) * len(
-            self._proto.data
-        ), f"{self.width * self.height} {(8 if in_bits else 1)*len(self._proto.data)}"
+        assert self.width * self.height == (8 if in_bits else 1) * len(self._proto.data), (
+            f"{self.width * self.height} {(8 if in_bits else 1) * len(self._proto.data)}"
+        )
         buffer_data = np.frombuffer(self._proto.data, dtype=np.uint8)
         if in_bits:
             buffer_data = np.unpackbits(buffer_data)
@@ -52,9 +52,9 @@ class PixelMap:
         """Example usage: self._game_info.pathing_grid[Point2((20, 20))] = 255"""
         assert 0 <= pos[0] < self.width, f"x is {pos[0]}, self.width is {self.width}"
         assert 0 <= pos[1] < self.height, f"y is {pos[1]}, self.height is {self.height}"
-        assert (
-            0 <= value <= 254 * self._in_bits + 1
-        ), f"value is {value}, it should be between 0 and {254 * self._in_bits + 1}"
+        assert 0 <= value <= 254 * self._in_bits + 1, (
+            f"value is {value}, it should be between 0 and {254 * self._in_bits + 1}"
+        )
         assert isinstance(value, int), f"value is of type {type(value)}, it should be an integer"
         self.data_numpy[pos[1], pos[0]] = value
 
