@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
-from typing import List
 
 from sc2.position import Point2
 
@@ -10,26 +11,26 @@ class PowerSource:
     radius: float
     unit_tag: int
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         assert self.radius > 0
 
     @classmethod
-    def from_proto(cls, proto):
+    def from_proto(cls, proto) -> PowerSource:
         return PowerSource(Point2.from_proto(proto.pos), proto.radius, proto.tag)
 
     def covers(self, position: Point2) -> bool:
         return self.position.distance_to(position) <= self.radius
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"PowerSource({self.position}, {self.radius})"
 
 
 @dataclass
 class PsionicMatrix:
-    sources: List[PowerSource]
+    sources: list[PowerSource]
 
     @classmethod
-    def from_proto(cls, proto):
+    def from_proto(cls, proto) -> PsionicMatrix:
         return PsionicMatrix([PowerSource.from_proto(p) for p in proto])
 
     def covers(self, position: Point2) -> bool:
