@@ -1,10 +1,9 @@
-# pylint: disable=R0904
 class ScoreDetails:
     """Accessable in self.state.score during step function
     For more information, see https://github.com/Blizzard/s2client-proto/blob/master/s2clientprotocol/score.proto
     """
 
-    def __init__(self, proto):
+    def __init__(self, proto) -> None:
         self._data = proto
         self._proto = proto.score_details
 
