@@ -535,4 +535,44 @@ VERSIONS = [
         "replay-hash": "A79CD3B6C6DADB0ECAEFA06E6D18E47B",
         "version": 88500,
     },
+    {
+        "base-version": 89720,
+        "data-hash": "D371D4D7D1E6C131B24A09FC0E758547",
+        "fixed-hash": "F3853B6E3B6013415CAC30EF3B27564B",
+        "label": "5.0.11",
+        "replay-hash": "A79CD3B6C6DADB0ECAEFA06E6D18E47B",
+        "version": 89720,
+    },
+    {
+        "base-version": 91115,
+        "data-hash": "7857A76754FEB47C823D18993C476BF0",
+        "fixed-hash": "99E19D19DA59112C1744A83CB49614A5",
+        "label": "5.0.12",
+        "replay-hash": "BE64E420B329BD2A7D10EEBC0039D6E5",
+        "version": 89720,
+    },
+    {
+        "base-version": 92028,
+        "data-hash": "2B7746A6706F919775EF1BADFC95EA1C",
+        "fixed-hash": "163B1CDF46F09B621F6312CD6901228E",
+        "label": "5.0.13",
+        "replay-hash": "BE64E420B329BD2A7D10EEBC0039D6E5",
+        "version": 92028,
+    },
+    {
+        "base-version": 93333,
+        "data-hash": "446907060311fb1cc29eb31e547bb9fd",
+        "fixed-hash": "BE86048D1DCE8650E1655D2FE2B665A8",
+        "label": "5.0.14.93333",
+        "replay-hash": "BE64E420B329BD2A7D10EEBC0039D6E5",
+        "version": 93333,
+    },
+    {
+        "base-version": 94137,
+        "data-hash": "519EE8D06E384469C652DD58FC6016AC",
+        "fixed-hash": "B100C340B3D0797CBE914AE091A68653",
+        "label": "5.0.14.94137",
+        "replay-hash": "BE64E420B329BD2A7D10EEBC0039D6E5",
+        "version": 94137,
+    },
 ]
